require 'chef/mixin/shell_out'
require 'chef/mixin/checksum'
require 'chef/mixin/command'
require 'chef/mixin/convert_to_class_name'
require 'chef/mixin/create_path'
require 'chef/mixin/deep_merge'
require 'chef/mixin/enforce_ownership_and_permissions'
require 'chef/mixin/from_file'
require 'chef/mixin/params_validate'
require 'chef/mixin/path_sanity'
require 'chef/mixin/template'
require 'chef/mixin/securable'
require 'chef/mixin/xml_escape'

